==> xl-react-components-0.16.62.tgz: package/tests/e2e/scenario/form/xl-dip-dynamic-form-default-required-scenario.js <==
import {Window} from 'protractor-base-dsl';
import Form from '../../dsl/component/form/form';
import Navigation from '../../dsl/common/navigation';
import TestBindings from '../../dsl/common/test-bindings';

describe('XL Dip Dynamic Form Default Required Scenario', () => {
    beforeAll(() => {
        Navigation.openFormElement('dynamicFormDefault');
        TestBindings.toggleRequired();
    });

    afterAll(() => {
        TestBindings.toggleRequired();
        Window.refresh();
    });

    it('should have all fields pristine and valid', () => {
        Form.expectAllFieldsArePristine();
        Form.expectAllFieldsAreValid();
    });

    it('should properly display default values', () => {
        Form.expectFieldHasValue('Label component String', 'input', 'component-0');
        Form.expectFieldHasValue('Label component StringWithTypeHint', 'input', 'string');
        Form.expectFieldHasText('Label component StringLarge', 'textarea', 'large string');
        Form.expectFieldHasValue('Label component Integer', 'input', 22);
        Form.expectDipSetOfStringsHasTags('Label component Set', ['apple', 'grape']);
        Form.expectDipCollectionHasValues('Label component List', ['tangerine', 'mango']);
        Form.expectFieldHasValue('Label component CI', 'input', 'CiName');
        Form.expectDipMapHasEntry('Label component Map String String', 1, 'someKey', 'someValue');
        const setOfCiValues = [
            'Applications/TestApp/1.0',
            'Infrastructure/TomcatHost',
            'Applications/ZooApp/1.0',
            'Applications/ZooApp/2.0'
        ];
        Form.expectDipCollectionHasValues('Label component Set Of CI', setOfCiValues);
        Form.expectDipCollectionHasValues('Label component List Of CI', ['List Item 1']);
        Form.expectDateTimeToEqual('Label component Date Time', 'Nov 9, 2016', '3:10 PM');
    });

    it('should have proper model', () => {
        Form.expectModelToEqual({
            nameComponentString: 'component-0',
            nameComponentStringWithTypeHint: 'string',
            nameComponentStringLarge: 'large string',
            nameComponentInteger: '22',
            nameComponentBoolean: true,
            nameComponentSet: ['apple', 'grape'],
            nameComponentList: [
                'tangerine',
                'mango'
            ],
            nameComponentCi: 'CiName',
            nameStringEnum: 'mario',
            mapStringStringName: {someKey: 'someValue'},
            nameSetOfCi: [
                'Applications/TestApp/1.0',
                'Infrastructure/TomcatHost',
                'Applications/ZooApp/1.0',
                'Applications/ZooApp/2.0'
            ],
            nameListOfCi: ['List Item 1'],
            datetimeName: 'November 9th 2016, 3:10:00 pm',
            datetimeStringName: 'November 9th 2017, 3:10:00 pm'
        });
    });

    it('should properly behave in display mode', () => {
        TestBindings.displayModeDisplay();

        Form.expectFieldReadonly('input', 'Label component String');
        Form.expectFieldDisabled('Label component StringWithTypeHint');
        Form.expectFieldReadonly('textarea', 'Label component StringLarge');
        Form.expectFieldDisabled('Label component Integer');
        Form.expectFieldDisabled('Label component Boolean');
        Form.expectDipStringsDisabled('Label component Set');
        Form.expectFieldNotPresent('Label component List', 'input');
        Form.expectFieldDisabled('Label component CI');
        Form.expectFieldDisabled('Label String enum');
        Form.expectDipMapDisabled('Label component Map String String');

        TestBindings.displayModeCreation();
    });

    it('should properly behave when form disabled', () => {
        TestBindings.toggleDisabled();

        Form.expectFieldReadonly('input', 'Label component String');
        Form.expectFieldDisabled('Label component StringWithTypeHint');
        Form.expectFieldReadonly('textarea', 'Label component StringLarge');
        Form.expectFieldDisabled('Label component Integer');
        Form.expectFieldDisabled('Label component Boolean');
        Form.expectDipStringsDisabled('Label component Set');
        Form.expectFieldDisabled('Label component List', 'input');
        Form.expectFieldDisabled('Label component CI');
        Form.expectFieldDisabled('Label String enum');
        Form.expectDipMapDisabled('Label component Map String String');

        TestBindings.toggleDisabled();
    });

    it('should show errors if to clean up the value', () => {
        TestBindings.toggleShowMessages();

        const stringDescription = 'Description component String (Property: nameComponentString)';
        Form.checkDescriptionAndErrorMessage('Label component String', stringDescription);

        const hintDescription = 'Description component String (Property: nameComponentStringWithTypeHint)';
        Form.checkDescriptionAndErrorMessage('Label component StringWithTypeHint', hintDescription);

        const largeStringDescription = 'Description component StringLarge (Property: nameComponentStringLarge)';
        Form.checkDescriptionAndErrorMessage('Label component StringLarge', largeStringDescription);

        const integerDescription = 'Description component Integer (Property: nameComponentInteger)';
        Form.checkDescriptionAndErrorMessage('Label component Integer', integerDescription);

        const setDescription = 'Description component Set (Property: nameComponentSet)';
        Form.checkDescriptionAndErrorMessage('Label component Set', setDescription, [
            Form.removeFirstTag,
            Form.removeFirstTag
        ]);

        const listDescription = 'Description component List (Property: nameComponentList)';
        Form.checkDescriptionAndErrorMessage('Label component List', listDescription, [
            Form.removeFirstCollectionItem,
            Form.removeFirstCollectionItem
        ]);

        const ciDescription = 'Description component CI (Property: nameComponentCi)';
        Form.checkDescriptionAndErrorMessage('Label component CI', ciDescription);

        const enumDescription = 'Description enum of string (Property: nameStringEnum)';
        Form.checkDescriptionAndErrorMessage('Label String enum', enumDescription);

        const mapDescription = 'Description component Map String String (Property: mapStringStringName)';
        Form.checkDescriptionAndErrorMessage('Label component Map String String', mapDescription, [
            Form.removeFirstMapEntry
        ]);

        const setOfCiDescription = 'Description component Set Of CI (Property: nameSetOfCi)';
        Form.checkDescriptionAndErrorMessage('Label component Set Of CI', setOfCiDescription, [
            Form.removeFirstCollectionItem,
            Form.removeFirstCollectionItem,
            Form.removeFirstCollectionItem,
            Form.removeFirstCollectionItem
        ]);

        const listOfCiDescription = 'Description component List Of CI (Property: nameListOfCi)';
        Form.checkDescriptionAndErrorMessage('Label component List Of CI', listOfCiDescription, [
            Form.removeFirstCollectionItem
        ]);

        TestBindings.toggleShowMessages();
    });
});

==> xl-react-components-0.21.15.tgz: package/tests/e2e/scenario/form/xl-dip-dynamic-form-default-required-scenario.js <==
import {Window} from 'protractor-base-dsl';
import Form from '../../dsl/component/form/form';
import Navigation from '../../dsl/common/navigation';
import TestBindings from '../../dsl/common/test-bindings';

describe('XL Dip Dynamic Form Default Required Scenario', () => {
    beforeAll(() => {
        Navigation.openFormElement('dynamicFormDefault');
        TestBindings.toggleRequired();
    });

    afterAll(() => {
        TestBindings.toggleRequired();
        Window.refresh();
    });

    it('should have all fields pristine and valid', () => {
        Form.expectAllFieldsArePristine();
        Form.expectAllFieldsAreValid();
    });

    it('should properly display default values', () => {
        Form.expectFieldHasValue('Label component String', 'input', 'component-0');
        Form.expectFieldHasValue('Label component StringWithTypeHint', 'input', 'string');
        Form.expectFieldHasText('Label component StringLarge', 'textarea', 'large string');
        Form.expectFirstLineMonacoFieldHasText('Label component StringMonaco', 'monaco string');
        Form.expectFieldHasValue('Label component Integer', 'input', 22);
        Form.expectDipSetOfStringsHasTags('Label component Set', ['apple', 'grape']);
        Form.expectDipCollectionHasValues('Label component List', ['tangerine', 'mango']);
        Form.expectFieldHasValue('Label component CI', 'input', 'CiName');
        Form.expectFieldHasValue('Label String enum', 'input', 'mario');
        Form.expectFieldHasValue('Label Radio enum', 'input', 'mario');
        Form.expectDipMapHasEntry('Label component Map String String', 1, 'someKey', 'someValue');
        const setOfCiValues = [
            'Applications/TestApp/1.0',
            'Infrastructure/TomcatHost',
            'Applications/ZooApp/1.0',
            'Applications/ZooApp/2.0'
        ];
        Form.expectDipCollectionHasValues('Label component Set Of CI', setOfCiValues);
        Form.expectDipCollectionHasValues('Label component List Of CI', ['List Item 1']);
        Form.expectDateTimeToEqual('Label component Date Time', 'Nov 9, 2016', '3:10 PM');
        Form.expectDateTimeToEqual('Label component Date Time With String Input', 'Nov 9, 2017', '3:10 PM');
    });

    it('should have proper model', () => {
        Form.expectModelToEqual({
            nameComponentString: 'component-0',
            nameComponentStringWithTypeHint: 'string',
            nameComponentStringLarge: 'large string',
            nameComponentStringMonaco: 'monaco string',
            nameComponentInteger: '22',
            nameComponentBoolean: true,
            nameComponentSet: ['apple', 'grape'],
            nameComponentList: [
                'tangerine',
                'mango'
            ],
            nameComponentCi: 'CiName',
            nameStringEnum: 'mario',
            nameRadioEnum: 'mario',
            mapStringStringName: {someKey: 'someValue'},
            nameSetOfCi: [
                'Applications/TestApp/1.0',
                'Infrastructure/TomcatHost',
                'Applications/ZooApp/1.0',
                'Applications/ZooApp/2.0'
            ],
            nameListOfCi: ['List Item 1', 'Application1'],
            datetimeName: 'November 9th 2016, 3:10:00 pm',
            datetimeStringName: 'November 9th 2017, 3:10:00 pm'
        });
    });

    it('should properly behave in display mode', () => {
        TestBindings.displayModeDisplay();

        Form.expectFieldReadonly('input', 'Label component String');
        Form.expectFieldDisabled('Label component StringWithTypeHint');
        Form.expectFieldReadonly('textarea', 'Label component StringLarge');
        Form.expectMonacoFieldReadonly('Label component StringMonaco');
        Form.expectFieldDisabled('Label component Integer');
        Form.expectFieldDisabled('Label component Boolean');
        Form.expectDipStringsDisabled('Label component Set');
        Form.expectFieldNotPresent('Label component List', 'input');
        Form.expectFieldDisabled('Label component CI');
        Form.expectFieldDisabled('Label String enum');
        Form.expectFieldDisabled('Label Radio enum');
        Form.expectDipMapDisabled('Label component Map String String');

        TestBindings.displayModeCreation();
    });

    it('should properly behave when form disabled', () => {
        TestBindings.toggleDisabled();

        Form.expectFieldReadonly('input', 'Label component String');
        Form.expectFieldDisabled('Label component StringWithTypeHint');
        Form.expectFieldReadonly('textarea', 'Label component StringLarge');
        Form.expectMonacoFieldReadonly('Label component StringMonaco');
        Form.expectFieldDisabled('Label component Integer');
        Form.expectFieldDisabled('Label component Boolean');
        Form.expectDipStringsDisabled('Label component Set');
        Form.expectFieldDisabled('Label component List', 'input');
        Form.expectFieldDisabled('Label component CI');
        Form.expectFieldDisabled('Label String enum');
        Form.expectFieldDisabled('Label Radio enum');
        Form.expectDipMapDisabled('Label component Map String String');

        TestBindings.toggleDisabled();
    });

    it('should show errors if to clean up the value', () => {
        const invalidCisMessage = 'One or more configuration item is invalid';
        TestBindings.toggleShowMessages();

        const stringDescription = 'Description component String (Property: nameComponentString)';
        Form.checkDescriptionAndErrorMessage('Label component String', stringDescription);

        const hintDescription = 'Description component String (Property: nameComponentStringWithTypeHint)';
        Form.checkDescriptionAndErrorMessage('Label component StringWithTypeHint', hintDescription);

        const largeStringDescription = 'Description component StringLarge (Property: nameComponentStringLarge)';
        Form.checkDescriptionAndErrorMessage('Label component StringLarge', largeStringDescription);

        const monacoStringDescription = 'Description component StringMonaco (Property: nameComponentStringMonaco)';
        Form.checkDescriptionAndErrorMessage('Label component StringMonaco', monacoStringDescription);

        const integerDescription = 'Description component Integer (Property: nameComponentInteger)';
        Form.checkDescriptionAndErrorMessage('Label component Integer', integerDescription);

        const setDescription = 'Description component Set (Property: nameComponentSet)';
        Form.checkDescriptionAndErrorMessage('Label component Set', setDescription, [
            Form.removeFirstTag,
            Form.removeFirstTag
        ]);

        const listDescription = 'Description component List (Property: nameComponentList)';
        Form.checkDescriptionAndErrorMessage('Label component List', listDescription, [
            Form.removeFirstCollectionItem,
            Form.removeFirstCollectionItem
        ]);

        const ciDescription = 'Description component CI (Property: nameComponentCi)';
        Form.checkDescriptionAndErrorMessage('Label component CI', ciDescription);

        const enumDescription = 'Description enum of string (Property: nameStringEnum)';
        Form.checkDescriptionAndErrorMessage('Label String enum', enumDescription);

        const enumRadioDescription = 'Description enum of strings as radio (Property: nameRadioEnum)';
        Form.expectDescription('Label Radio enum', enumRadioDescription);

        const mapDescription = 'Description component Map String String (Property: mapStringStringName)';
        Form.checkDescriptionAndErrorMessage('Label component Map String String', mapDescription, [
            Form.removeFirstMapEntry
        ]);

        const setOfCiLabel = 'Label component Set Of CI';
        Form.expectDescription(setOfCiLabel, invalidCisMessage);
        Form.removeCollectionItemByIndex(setOfCiLabel, 4);
        const setOfCiDescription = 'Description component Set Of CI (Property: nameSetOfCi)';

        Form.checkDescriptionAndErrorMessage(setOfCiLabel, setOfCiDescription, [
            Form.removeFirstCollectionItem,
            Form.removeFirstCollectionItem,
            Form.removeFirstCollectionItem
        ]);

        const listOfCiLabel = 'Label component List Of CI';
        Form.expectDescription(listOfCiLabel, invalidCisMessage);
        Form.removeCollectionItemByIndex(listOfCiLabel, 2);

        const listOfCiDescription = 'Description component List Of CI (Property: nameListOfCi)';
        Form.checkDescriptionAndErrorMessage(listOfCiLabel, listOfCiDescription, [
            Form.removeFirstCollectionItem
        ]);

        TestBindings.toggleShowMessages();
    });
});
